==> mediatex-0.2.tar.gz: mediatex-0.2/src/misc/utSetuid.sh <==
#!/bin/bash
#=======================================================================
# * Version: $Id: utSetuid.sh,v 1.2 2014/11/13 16:36:54 nroche Exp $
# * Project: MediaTex
# * Module:  miscellaneous modules
# *
# * Unit test script for setuid.c
#
# MediaTex is an Electronic Records Management System
# Copyright (C) 2014  Nicolas Roche
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#=======================================================================
set -e
#set -x

if [ $(id -u) -ne 0 ]; then
    echo -n "(root needed for this test) "
    exit 0
fi

# retrieve environment
[ -z $srcdir ] && srcdir=.
. ${srcdir}/../utMediatex.sh

chown root.root utsetuid
chmod u+s utsetuid

adduser \
 --quiet --system --group --shell /bin/bash --no-create-home \
 ut-mdtx-user1 
adduser \
 --quiet --system --group --shell /bin/bash --no-create-home \
 ut-mdtx-user2

addgroup ut-mdtx-user1 ut-mdtx-user2 >/dev/null

#echo su ut-mdtx-user1 -c \"./utsetuid -X -u ut-mdtx-user2 -i $PWD/user.sh\"
#su ut-mdtx-user1 -c "./utsetuid -X -u ut-mdtx-user2 -i $PWD/user.sh"
#exit

su ut-mdtx-user1 -c \
    "./utsetuid -X -s notice -u ut-mdtx-user2 -i $PWD/user.sh" \
    >ut.out 2>&1

deluser --quiet ut-mdtx-user2 2>/dev/null
deluser --quiet ut-mdtx-user1
delgroup --quiet ut-mdtx-user2

# compare with the expected output
mrProperOutputs
diff $srcdir/utSetuid.exp ut.out

==> mediatex-0.3.tar.gz: mediatex-0.3/src/misc/utSetuid.sh <==
#!/bin/bash
#=======================================================================
# * Version: $Id: utSetuid.sh,v 1.3 2015/06/03 14:03:50 nroche Exp $
# * Project: MediaTex
# * Module:  miscellaneous modules
# *
# * Unit test script for setuid.c
#
# MediaTex is an Electronic Records Management System
# Copyright (C) 2014 2015 Nicolas Roche
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#=======================================================================
set -e
#set -x

if [ $(id -u) -ne 0 ]; then
    echo -n "(root needed for this test) "
    exit 0
fi

# retrieve environment
[ -z $srcdir ] && srcdir=.
. ${srcdir}/../utMediatex.sh

chown root.root utsetuid
chmod u+s utsetuid

adduser \
 --quiet --system --group --shell /bin/bash --no-create-home \
 ut-mdtx-user1 
adduser \
 --quiet --system --group --shell /bin/bash --no-create-home \
 ut-mdtx-user2

addgroup ut-mdtx-user1 ut-mdtx-user2 >/dev/null

#echo su ut-mdtx-user1 -c \"./utsetuid -S -u ut-mdtx-user2 -i $PWD/user.sh\"
#su ut-mdtx-user1 -c "./utsetuid -S -u ut-mdtx-user2 -i $PWD/user.sh"
#exit

su ut-mdtx-user1 -c \
    "./utsetuid -S -s notice -u ut-mdtx-user2 -i $PWD/user.sh" \
    >ut.out 2>&1

deluser --quiet ut-mdtx-user2 2>/dev/null
deluser --quiet ut-mdtx-user1
delgroup --quiet ut-mdtx-user2

# compare with the expected output
mrProperOutputs
diff $srcdir/utSetuid.exp ut.out
